<?php
/*
 * $Horde: nag/list.php,v 1.14 2001/06/04 21:49:08 chuck Exp $
 *
 * Copyright 2001 Jon Parise <jon@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

require_once './lib/base.php';

/* Get the current action ID.  Default to NO_ACTION. */
$actionID = Horde::getFormData('actionID', NO_ACTION);

/* Sort out the sorting values. */
if (isset($HTTP_GET_VARS['sortby'])) {
    $prefs->setValue('sortby', $HTTP_GET_VARS['sortby']);
}
if (isset($HTTP_GET_VARS['sortdir'])) {
   $prefs->setValue('sortdir', $HTTP_GET_VARS['sortdir']);
}

/* Create a Nag storage instance. */
require_once NAG_BASE . '/lib/Storage.php';
$storage = Nag_Storage::factory($conf['storage']['driver'], Auth::getAuth(),
    $conf['storage']['params']);
$storage->retrieve();

/* Get the full, sorted task list. */
$tasks = Nag::listTasks($storage, TASK_ANY, $prefs->getValue('sortby'),
                        $prefs->getValue('sortdir'));

/* Page variables. */
$i = 0;
$title = 'Current Tasks';

switch ($actionID) {
 case NAG_DELETE_TASKS:
     $items = Horde::getFormData('items');
     if (isset($items) && count($items > 0)) {
         foreach ($items as $task_id) {
             if (isset($tasks[$task_id])) {
                 $storage->deleteTask($task_id);
                 unset($tasks[$task_id]);
             }
         }
         
         if ($storage->store() === STORAGE_OK) {
             Horde::raiseMessage(sprintf(_("Deleted %d tasks."), count($items)), HORDE_SUCCESS);
         } else {
             Horde::raiseMessage(_("There was a problem deleting tasks."), HORDE_ERROR);
         }
     }
     break;

 case NAG_SEARCH_TASKS:
     /* If we're searching, only list those tasks that match the
        search result. */
     /* Get the search parameters. */
     $pattern = Horde::getFormData('search_pattern');
     $search_name = (Horde::getFormData('search_name') == 'on');
     $search_desc = (Horde::getFormData('search_desc') == 'on');
     
     if (!empty($pattern) && ($search_name || $search_desc)) {
         
         $search_result = array();
         foreach ($tasks as $task_id => $task) {
             if (($search_name && preg_match("/$pattern/i", $task['name'])) || 
                 ($search_desc && preg_match("/$pattern/i", $task['desc']))) {
                 $search_result[$task_id] = $task;
             }
         }
         
         /* Reassign $tasks to the search result. */
         $tasks = $search_result;
         $title = 'Search Results';
     }
     break;
}

require $conf['paths']['templates'] . '/common-header.inc';
require NAG_BASE . '/menu.php';
require NAG_BASE . '/status.php';
require $conf['paths']['templates'] . '/list/javascript.inc';
require $conf['paths']['templates'] . '/list/header.inc';
require $conf['paths']['templates'] . '/list/actions.inc';

if (count($tasks) > 0) {
    include $conf['paths']['templates'] . '/list/task_headers.inc';

    foreach ($tasks as $task_id => $task) {
        if (!empty($task['due']) && ($task['due'] < time())) {
            $style = 'overdue';
        } else {
            $style = 'text';
        }
        include $conf['paths']['templates'] . '/list/task_summaries.inc';
    }

    include $conf['paths']['templates'] . '/list/task_footers.inc';
    include $conf['paths']['templates'] . '/list/actions.inc';
} else {
    include $conf['paths']['templates'] . '/list/empty.inc';
}

require $conf['paths']['templates'] . '/list/footer.inc';
require $conf['paths']['templates'] . '/common-footer.inc';

$prefs->store();

?>
