<?php
/*
 * $Horde: nag/task.php,v 1.8 2001/06/04 21:49:09 chuck Exp $
 *
 * Copyright 2001 Jon Parise <jon@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

require_once './lib/base.php';

/* Redirect to the task list if no action has been requested. */
$actionID = Horde::getFormData('actionID', NO_ACTION);
if ($actionID === NO_ACTION) {
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

/* Create a Nag storage instance. */
require_once NAG_BASE . '/lib/Storage.php';
$storage = Nag_Storage::factory($conf['storage']['driver'], Auth::getAuth(),
    $conf['storage']['params']);
$storage->retrieve();

/* Retrieve the task list. */
$tasks = Nag::listTasks($storage);

/* Run through the action handlers. */
switch($actionID) {
case NAG_ADD_TASK:

    /* Set up the task attributes. */
    $task_id = null;
    $task_name = '';
    $task_due = 0;
    $task_desc = '';

    /* Set the initial due date to one week from now. */
    $initial_date = time() + 604800;
    $day_widget = Nag::buildDayWidget('due_day', $initial_date);
    $month_widget = Nag::buildMonthWidget('due_month', $initial_date);
    $year_widget = Nag::buildYearWidget('due_year', 3, $initial_date);
    $hour_widget = Nag::buildHourWidget('due_hour', $initial_date);
    $minute_widget = Nag::buildMinuteWidget('due_minute', 15);

    /* Set up the radio buttons. */
    $none_checked = ($task_due == 0) ? 'checked="checked" ' : '';
    $specified_checked = ($task_due != 0) ? 'checked="checked" ' : '';

    $title = 'Adding A New Task';

    break;

case NAG_MODIFY_TASK:

    $task_id = Horde::getFormData('task');

    if (isset($task_id) && isset($tasks[$task_id])) {

        /* Set up the task attributes. */
        $task_name = $tasks[$task_id]['name'];
        $task_due = $tasks[$task_id]['due'];
        $task_desc = $tasks[$task_id]['desc'];

        /* If the due date isn't set, set the widgets to the default. */
        $due_date = ($task_due > 0) ? $task_due : (time() + 604800);

        /* Set up the due date selection widgets. */
        $day_widget = Nag::buildDayWidget('due_day', $due_date);
        $month_widget = Nag::buildMonthWidget('due_month', $due_date);
        $year_widget = Nag::buildYearWidget('due_year', 3, $due_date);
        $hour_widget = Nag::buildHourWidget('due_hour', $due_date);
        $minute_widget = Nag::buildMinuteWidget('due_minute', 15, $due_date);

        /* Set up the radio buttons. */
        $none_checked = ($task_due == 0) ? 'checked="checked" ' : '';
        $specified_checked = ($task_due > 0) ? 'checked="checked" ' : '';

        $title = "Modifying '$task_name'";
    } else {
        $title = 'Unknown task';
    }

    break;

case NAG_SAVE_TASK:

    /* Get the form values. */
    $task_id = Horde::getFormData('task');
    $task_name = Horde::getFormData('task_name');
    $task_desc = Horde::getFormData('task_desc');
    $due_type = Horde::getFormData('due_type');
    $due_day = Horde::getFormData('due_day');
    $due_month = Horde::getFormData('due_month');
    $due_year = Horde::getFormData('due_year');
    $due_hour = Horde::getFormData('due_hour');
    $due_minute = Horde::getFormData('due_minute');

    /* Convert the due date to Unix time. */
    $due_str = "$due_month/$due_day/$due_year $due_hour:$due_minute";

    /* Set the due date according to the $due_type toggle. */
    $task_due = (strcasecmp($due_type, 'none')) ? strtotime($due_str) : 0;

    /*
     * If $task_id is set, we're modifying an existing task.  Otherwise,
     * we're adding a new task with the provided attributes.
     */
    if (!empty($task_id) && isset($tasks[$task_id])) {
        $storage->modifyTask($task_id, 'name', $task_name);
        $storage->modifyTask($task_id, 'desc', $task_desc);
        $storage->modifyTask($task_id, 'due', $task_due);
    } else {
        $storage->addTask($task_name, $task_desc, $task_due);
    }

    /* Store the changes. */
    $storage->store();

    /* Return to the task list. */
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;

    break;

case NAG_DELETE_TASKS:

    /* Delete the task if we're provided with a valid task ID to delete. */
    $task_id = Horde::getFormData('task');
    if (isset($task_id) && isset($tasks[$task_id])) {
        if ($storage->deleteTask($task_id)) {
            $storage->store();
        }
    }

    /* Return to the task list. */
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;

    break;

default:
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}


require $conf['paths']['templates'] . '/common-header.inc';
require NAG_BASE . '/menu.php';
require NAG_BASE . '/status.php';
require $conf['paths']['templates'] . '/task/begin.inc';
require $conf['paths']['templates'] . '/task/task.inc';
require $conf['paths']['templates'] . '/task/end.inc';
require $conf['paths']['templates'] . '/common-footer.inc';

$prefs->store();

?>
